# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: partitions_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17partitions_common.proto\x12\x1e\x61rmonik.api.grpc.v1.partitions\"\xa8\x02\n\x0cPartitionRaw\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1c\n\x14parent_partition_ids\x18\x02 \x03(\t\x12\x14\n\x0cpod_reserved\x18\x03 \x01(\x03\x12\x0f\n\x07pod_max\x18\x04 \x01(\x03\x12]\n\x11pod_configuration\x18\x07 \x03(\x0b\x32\x42.armonik.api.grpc.v1.partitions.PartitionRaw.PodConfigurationEntry\x12\x1d\n\x15preemption_percentage\x18\x05 \x01(\x03\x12\x10\n\x08priority\x18\x06 \x01(\x03\x1a\x37\n\x15PodConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xec\x06\n\x15ListPartitionsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12L\n\x06\x66ilter\x18\x03 \x01(\x0b\x32<.armonik.api.grpc.v1.partitions.ListPartitionsRequest.Filter\x12H\n\x04sort\x18\x04 \x01(\x0b\x32:.armonik.api.grpc.v1.partitions.ListPartitionsRequest.Sort\x1a\x89\x01\n\x06\x46ilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1b\n\x13parent_partition_id\x18\x02 \x01(\t\x12\x14\n\x0cpod_reserved\x18\x03 \x01(\x05\x12\x0f\n\x07pod_max\x18\x04 \x01(\x05\x12\x1d\n\x15preemption_percentage\x18\x05 \x01(\x05\x12\x10\n\x08priority\x18\x06 \x01(\x05\x1a\xb2\x01\n\x04Sort\x12Q\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x42.armonik.api.grpc.v1.partitions.ListPartitionsRequest.OrderByField\x12W\n\tdirection\x18\x02 \x01(\x0e\x32\x44.armonik.api.grpc.v1.partitions.ListPartitionsRequest.OrderDirection\"\xf2\x01\n\x0cOrderByField\x12\x1e\n\x1aORDER_BY_FIELD_UNSPECIFIED\x10\x00\x12\x15\n\x11ORDER_BY_FIELD_ID\x10\x01\x12\'\n#ORDER_BY_FIELD_PARENT_PARTITION_IDS\x10\x02\x12\x1f\n\x1bORDER_BY_FIELD_POD_RESERVED\x10\x03\x12\x1a\n\x16ORDER_BY_FIELD_POD_MAX\x10\x04\x12(\n$ORDER_BY_FIELD_PREEMPTION_PERCENTAGE\x10\x05\x12\x1b\n\x17ORDER_BY_FIELD_PRIORITY\x10\x06\"d\n\x0eOrderDirection\x12\x1f\n\x1bORDER_DIRECTION_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDER_DIRECTION_ASC\x10\x01\x12\x18\n\x14ORDER_DIRECTION_DESC\x10\x02\"\x8a\x01\n\x16ListPartitionsResponse\x12@\n\npartitions\x18\x01 \x03(\x0b\x32,.armonik.api.grpc.v1.partitions.PartitionRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"!\n\x13GetPartitionRequest\x12\n\n\x02id\x18\x01 \x01(\t\"W\n\x14GetPartitionResponse\x12?\n\tpartition\x18\x01 \x01(\x0b\x32,.armonik.api.grpc.v1.partitions.PartitionRawB!\xaa\x02\x1e\x41rmonik.Api.Grpc.V1.Partitionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'partitions_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\036Armonik.Api.Grpc.V1.Partitions'
  _PARTITIONRAW_PODCONFIGURATIONENTRY._options = None
  _PARTITIONRAW_PODCONFIGURATIONENTRY._serialized_options = b'8\001'
  _PARTITIONRAW._serialized_start=60
  _PARTITIONRAW._serialized_end=356
  _PARTITIONRAW_PODCONFIGURATIONENTRY._serialized_start=301
  _PARTITIONRAW_PODCONFIGURATIONENTRY._serialized_end=356
  _LISTPARTITIONSREQUEST._serialized_start=359
  _LISTPARTITIONSREQUEST._serialized_end=1235
  _LISTPARTITIONSREQUEST_FILTER._serialized_start=570
  _LISTPARTITIONSREQUEST_FILTER._serialized_end=707
  _LISTPARTITIONSREQUEST_SORT._serialized_start=710
  _LISTPARTITIONSREQUEST_SORT._serialized_end=888
  _LISTPARTITIONSREQUEST_ORDERBYFIELD._serialized_start=891
  _LISTPARTITIONSREQUEST_ORDERBYFIELD._serialized_end=1133
  _LISTPARTITIONSREQUEST_ORDERDIRECTION._serialized_start=1135
  _LISTPARTITIONSREQUEST_ORDERDIRECTION._serialized_end=1235
  _LISTPARTITIONSRESPONSE._serialized_start=1238
  _LISTPARTITIONSRESPONSE._serialized_end=1376
  _GETPARTITIONREQUEST._serialized_start=1378
  _GETPARTITIONREQUEST._serialized_end=1411
  _GETPARTITIONRESPONSE._serialized_start=1413
  _GETPARTITIONRESPONSE._serialized_end=1500
# @@protoc_insertion_point(module_scope)
