# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: partitions_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import partitions_common_pb2 as partitions__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18partitions_service.proto\x12\x1e\x61rmonik.api.grpc.v1.partitions\x1a\x17partitions_common.proto2\x8d\x02\n\nPartitions\x12\x81\x01\n\x0eListPartitions\x12\x35.armonik.api.grpc.v1.partitions.ListPartitionsRequest\x1a\x36.armonik.api.grpc.v1.partitions.ListPartitionsResponse\"\x00\x12{\n\x0cGetPartition\x12\x33.armonik.api.grpc.v1.partitions.GetPartitionRequest\x1a\x34.armonik.api.grpc.v1.partitions.GetPartitionResponse\"\x00\x42!\xaa\x02\x1e\x41rmonik.Api.Grpc.V1.Partitionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'partitions_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\036Armonik.Api.Grpc.V1.Partitions'
  _PARTITIONS._serialized_start=86
  _PARTITIONS._serialized_end=355
# @@protoc_insertion_point(module_scope)
